@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vtebg.c,v 1.9 2004/04/20 06:35:43 nalin Exp $"
+#ident "$Id: vtebg.c,v 1.10 2005/10/02 09:59:42 kmaraas Exp $"
 #include "../config.h"
 #include <stdio.h>
 #include <string.h>
@@ -112,7 +112,7 @@ _vte_property_get_pixmaps(GdkWindow *window, GdkAtom atom,
 			  XID **pixmaps)
 {
 	return gdk_property_get(window, atom, GDK_TARGET_PIXMAP,
-				0, INT_MAX,
+				0, INT_MAX - 3,
 				FALSE,
 				type, NULL, size,
 				(guchar**) pixmaps);
